@@ -12,7 +12,7 @@
 
 import uuid
 
-from fom.db import ITERABLE_TYPES, SERIALIZABLE_TYPES
+from fom.db import ITERABLE_TYPES, SERIALIZABLE_TYPES, PRIMITIVE_CONTENT_TYPE
 from fom.session import Fluid
 from fom.errors import Fluid404Error
 
@@ -270,6 +270,10 @@ class Tag(SessionBound):
         """
         self.api.delete()
 
+class UNKNOWN_VALUE(object):
+    """Used to indicate that a tag-value is, as yet, of undetermined value.
+    """
+    pass
 
 class readonly_tag_value(object):
     """Descriptor to provide a tag value lookup on an object to simulate a
@@ -287,8 +291,8 @@ class readonly_tag_value(object):
         if self.cached:
             value = instance.get_cached(self.tagpath)
         else:
-            value = None
-        if value is None:
+            value = UNKNOWN_VALUE()
+        if isinstance(value, UNKNOWN_VALUE):
             value = instance.get(self.tagpath)[0]
         return value
 
@@ -317,7 +321,12 @@ class tag_value(readonly_tag_value):
         """
         super(tag_value, self).__init__(tagpath, cached)
         self.content_type = content_type
-        self.lazy_save = lazy_save
+        # if the content type isn't for a primitive content type then it can't
+        # be lazy saved
+        if content_type and content_type != PRIMITIVE_CONTENT_TYPE:
+            self.lazy_save = False
+        else:
+            self.lazy_save = lazy_save
 
     def __set__(self, instance, value):
         if self.lazy_save:
@@ -378,7 +387,7 @@ class Object(SessionBound):
     def get_cached(self, tagpath):
         """Get the cached value of a tag.
         """
-        return self._cache.get(tagpath)
+        return self._cache.get(tagpath, UNKNOWN_VALUE())
 
     def refresh(self, *tagpaths):
         """
